#!/usr/bin/env python
from setuptools import setup


setup(
    setup_requires=['pbr>=3.0', 'setuptools>=17.1'],
    pbr=True,
    python_requires=">=3.6.*",
    long_description_content_type='text/markdown; charset=UTF-8',
)
